==> estruttura-2.0.0.tar.gz: estruttura-2.0.0/estruttura/__init__.py <==
from ._attribute import Attribute, MutableAttribute, deleter, getter, setter
from ._bases import (
    BaseCollectionStructure,
    BaseImmutableCollectionStructure,
    BaseImmutableStructure,
    BaseMutableCollectionStructure,
    BaseMutableStructure,
    BaseProxyCollectionStructure,
    BaseProxyImmutableCollectionStructure,
    BaseProxyImmutableStructure,
    BaseProxyMutableCollectionStructure,
    BaseProxyMutableStructure,
    BaseProxyStructure,
    BaseProxyStructureMeta,
    BaseProxyUserCollectionStructure,
    BaseProxyUserImmutableCollectionStructure,
    BaseProxyUserImmutableStructure,
    BaseProxyUserMutableCollectionStructure,
    BaseProxyUserMutableStructure,
    BaseProxyUserStructure,
    BaseStructure,
    BaseStructureMeta,
    BaseUserCollectionStructure,
    BaseUserImmutableCollectionStructure,
    BaseUserImmutableStructure,
    BaseUserMutableCollectionStructure,
    BaseUserMutableStructure,
    BaseUserStructure,
)
from ._dict import (
    DictStructure,
    ImmutableDictStructure,
    MutableDictStructure,
    ProxyDictStructure,
    ProxyImmutableDictStructure,
    ProxyMutableDictStructure,
    ProxyUserDictStructure,
    ProxyUserImmutableDictStructure,
    ProxyUserMutableDictStructure,
    UserDictStructure,
    UserImmutableDictStructure,
    UserMutableDictStructure,
)
from ._helpers import (
    attribute,
    auto_caller_module,
    dict_attribute,
    dict_cls,
    list_attribute,
    list_cls,
    set_attribute,
    set_cls,
)
from ._list import (
    ImmutableListStructure,
    ListStructure,
    MutableListStructure,
    ProxyImmutableListStructure,
    ProxyListStructure,
    ProxyMutableListStructure,
    ProxyUserImmutableListStructure,
    ProxyUserListStructure,
    ProxyUserMutableListStructure,
    UserImmutableListStructure,
    UserListStructure,
    UserMutableListStructure,
)
from ._relationship import Relationship, RelationshipTypesInfo
from ._set import (
    ImmutableSetStructure,
    MutableSetStructure,
    ProxyImmutableSetStructure,
    ProxyMutableSetStructure,
    ProxySetStructure,
    ProxyUserImmutableSetStructure,
    ProxyUserMutableSetStructure,
    ProxyUserSetStructure,
    SetStructure,
    UserImmutableSetStructure,
    UserMutableSetStructure,
    UserSetStructure,
)
from ._structure import (
    AttributeMap,
    ImmutableStructure,
    MutableStructure,
    ProxyImmutableStructure,
    ProxyMutableStructure,
    ProxyStructure,
    ProxyStructureMeta,
    ProxyUserImmutableStructure,
    ProxyUserMutableStructure,
    ProxyUserStructure,
    Structure,
    StructureMeta,
    UserImmutableStructure,
    UserMutableStructure,
    UserStructure,
)

__all__ = [
    "Attribute",
    "MutableAttribute",
    "getter",
    "setter",
    "deleter",
    "BaseStructureMeta",
    "BaseStructure",
    "BaseUserStructure",
    "BaseProxyStructureMeta",
    "BaseProxyStructure",
    "BaseProxyUserStructure",
    "BaseImmutableStructure",
    "BaseUserImmutableStructure",
    "BaseMutableStructure",
    "BaseUserMutableStructure",
    "BaseProxyImmutableStructure",
    "BaseProxyUserImmutableStructure",
    "BaseProxyMutableStructure",
    "BaseProxyUserMutableStructure",
    "BaseCollectionStructure",
    "BaseUserCollectionStructure",
    "BaseProxyCollectionStructure",
    "BaseProxyUserCollectionStructure",
    "BaseImmutableCollectionStructure",
    "BaseUserImmutableCollectionStructure",
    "BaseProxyImmutableCollectionStructure",
    "BaseProxyUserImmutableCollectionStructure",
    "BaseMutableCollectionStructure",
    "BaseUserMutableCollectionStructure",
    "BaseProxyMutableCollectionStructure",
    "BaseProxyUserMutableCollectionStructure",
    "AttributeMap",
    "StructureMeta",
    "Structure",
    "UserStructure",
    "ProxyStructureMeta",
    "ProxyStructure",
    "ProxyUserStructure",
    "ImmutableStructure",
    "UserImmutableStructure",
    "ProxyImmutableStructure",
    "ProxyUserImmutableStructure",
    "MutableStructure",
    "UserMutableStructure",
    "ProxyMutableStructure",
    "ProxyUserMutableStructure",
    "DictStructure",
    "UserDictStructure",
    "ProxyDictStructure",
    "ProxyUserDictStructure",
    "ImmutableDictStructure",
    "UserImmutableDictStructure",
    "ProxyImmutableDictStructure",
    "ProxyUserImmutableDictStructure",
    "MutableDictStructure",
    "UserMutableDictStructure",
    "ProxyMutableDictStructure",
    "ProxyUserMutableDictStructure",
    "ListStructure",
    "UserListStructure",
    "ProxyListStructure",
    "ProxyUserListStructure",
    "ImmutableListStructure",
    "UserImmutableListStructure",
    "ProxyImmutableListStructure",
    "ProxyUserImmutableListStructure",
    "MutableListStructure",
    "UserMutableListStructure",
    "ProxyMutableListStructure",
    "ProxyUserMutableListStructure",
    "Relationship",
    "RelationshipTypesInfo",
    "SetStructure",
    "UserSetStructure",
    "ProxySetStructure",
    "ProxyUserSetStructure",
    "ImmutableSetStructure",
    "UserImmutableSetStructure",
    "ProxyImmutableSetStructure",
    "ProxyUserImmutableSetStructure",
    "MutableSetStructure",
    "UserMutableSetStructure",
    "ProxyMutableSetStructure",
    "ProxyUserMutableSetStructure",
    "dict_cls",
    "list_cls",
    "set_cls",
    "auto_caller_module",
    "attribute",
    "dict_attribute",
    "list_attribute",
    "set_attribute",
]

==> estruttura-3.0.0.tar.gz: estruttura-3.0.0/estruttura/__init__.py <==
from ._attribute import (
    Attribute,
    AttributedProtocol,
    MutableAttribute,
    MutableAttributedProtocol,
    deleter,
    get_global_attribute_count,
    getter,
    setter,
)
from ._bases import (
    BaseCollectionStructure,
    BaseImmutableCollectionStructure,
    BaseImmutableStructure,
    BaseMutableCollectionStructure,
    BaseMutableStructure,
    BaseStructure,
    BaseStructureMeta,
    BaseUserCollectionStructure,
    BaseUserImmutableCollectionStructure,
    BaseUserImmutableStructure,
    BaseUserMutableCollectionStructure,
    BaseUserMutableStructure,
    BaseUserStructure,
)
from ._dict import (
    DictStructure,
    ImmutableDictStructure,
    MutableDictStructure,
    UserDictStructure,
    UserImmutableDictStructure,
    UserMutableDictStructure,
)
from ._helpers import (
    attribute,
    dict_attribute,
    dict_cls,
    list_attribute,
    list_cls,
    set_attribute,
    set_cls,
)
from ._list import (
    ImmutableListStructure,
    ListStructure,
    MutableListStructure,
    UserImmutableListStructure,
    UserListStructure,
    UserMutableListStructure,
    pre_move,
    resolve_continuous_slice,
    resolve_index,
)
from ._relationship import Relationship, RelationshipTypesInfo
from ._set import (
    ImmutableSetStructure,
    MutableSetStructure,
    SetStructure,
    UserImmutableSetStructure,
    UserMutableSetStructure,
    UserSetStructure,
)
from ._structure import (
    AttributeMap,
    ImmutableStructure,
    MutableStructure,
    Structure,
    StructureMeta,
    UserImmutableStructure,
    UserMutableStructure,
    UserStructure,
)

__all__ = [
    "Attribute",
    "MutableAttribute",
    "getter",
    "setter",
    "deleter",
    "get_global_attribute_count",
    "BaseStructureMeta",
    "BaseStructure",
    "BaseUserStructure",
    "BaseImmutableStructure",
    "BaseUserImmutableStructure",
    "BaseMutableStructure",
    "BaseUserMutableStructure",
    "BaseCollectionStructure",
    "BaseUserCollectionStructure",
    "BaseImmutableCollectionStructure",
    "BaseUserImmutableCollectionStructure",
    "BaseMutableCollectionStructure",
    "BaseUserMutableCollectionStructure",
    "AttributeMap",
    "StructureMeta",
    "Structure",
    "UserStructure",
    "ImmutableStructure",
    "UserImmutableStructure",
    "MutableStructure",
    "UserMutableStructure",
    "DictStructure",
    "UserDictStructure",
    "ImmutableDictStructure",
    "UserImmutableDictStructure",
    "MutableDictStructure",
    "UserMutableDictStructure",
    "ListStructure",
    "UserListStructure",
    "ImmutableListStructure",
    "UserImmutableListStructure",
    "MutableListStructure",
    "UserMutableListStructure",
    "resolve_index",
    "resolve_continuous_slice",
    "pre_move",
    "Relationship",
    "RelationshipTypesInfo",
    "SetStructure",
    "UserSetStructure",
    "ImmutableSetStructure",
    "UserImmutableSetStructure",
    "MutableSetStructure",
    "UserMutableSetStructure",
    "dict_cls",
    "list_cls",
    "set_cls",
    "attribute",
    "dict_attribute",
    "list_attribute",
    "set_attribute",
]
